@@ -40,6 +40,9 @@ def _django_db_setup(request,
 
     _handle_south()
 
+    if request.config.getvalue('nomigrations'):
+        _disable_native_migrations()
+
     with _django_cursor_wrapper:
         # Monkey patch Django's setup code to support database re-use
         if request.config.getvalue('reuse_db'):
@@ -47,7 +50,8 @@ def _django_db_setup(request,
                 monkey_patch_creation_for_db_reuse()
 
         # Create the database
-        db_cfg = setup_databases(verbosity=0, interactive=False)
+        db_cfg = setup_databases(verbosity=pytest.config.option.verbose,
+                                 interactive=False)
 
     def teardown_database():
         with _django_cursor_wrapper:
@@ -58,75 +62,96 @@ def _django_db_setup(request,
 
 
 def _django_db_fixture_helper(transactional, request, _django_cursor_wrapper):
-    if is_django_unittest(request.node):
+    if is_django_unittest(request):
         return
 
+    if not transactional and 'live_server' in request.funcargnames:
+        # Do nothing, we get called with transactional=True, too.
+        return
+
+    django_case = None
+
+    _django_cursor_wrapper.enable()
+    request.addfinalizer(_django_cursor_wrapper.disable)
+
     if transactional:
-        _django_cursor_wrapper.enable()
+        from django import get_version
 
-        def flushdb():
-            """Flush the database and close database connections"""
-            # Django does this by default *before* each test
-            # instead of after.
-            from django.db import connections
-            from django.core.management import call_command
+        if get_version() >= '1.5':
+            from django.test import TransactionTestCase as django_case
 
-            for db in connections:
-                call_command('flush', verbosity=0,
-                             interactive=False, database=db)
-            for conn in connections.all():
-                conn.close()
+        else:
+            # Django before 1.5 flushed the DB during setUp.
+            # Use pytest-django's old behavior with it.
+            def flushdb():
+                """Flush the database and close database connections"""
+                # Django does this by default *before* each test
+                # instead of after.
+                from django.db import connections
+                from django.core.management import call_command
+
+                for db in connections:
+                    call_command('flush', interactive=False, database=db,
+                                 verbosity=pytest.config.option.verbose)
+                for conn in connections.all():
+                    conn.close()
+            request.addfinalizer(flushdb)
 
-        request.addfinalizer(_django_cursor_wrapper.disable)
-        request.addfinalizer(flushdb)
     else:
-        if 'live_server' in request.funcargnames:
-            return
-        from django.test import TestCase
+        from django.test import TestCase as django_case
 
-        _django_cursor_wrapper.enable()
-        _django_cursor_wrapper._is_transactional = False
-        case = TestCase(methodName='__init__')
+    if django_case:
+        case = django_case(methodName='__init__')
         case._pre_setup()
-        request.addfinalizer(_django_cursor_wrapper.disable)
         request.addfinalizer(case._post_teardown)
 
 
 def _handle_south():
     from django.conf import settings
-    if 'south' in settings.INSTALLED_APPS:
-        # Handle south.
-        from django.core import management
 
-        try:
-            # if `south` >= 0.7.1 we can use the test helper
-            from south.management.commands import patch_for_test_db_setup
-        except ImportError:
-            # if `south` < 0.7.1 make sure it's migrations are disabled
-            management.get_commands()
-            management._commands['syncdb'] = 'django.core'
-        else:
-            # Monkey-patch south.hacks.django_1_0.SkipFlushCommand to load
-            # initial data.
-            # Ref: http://south.aeracode.org/ticket/1395#comment:3
-            import south.hacks.django_1_0
-            from django.core.management.commands.flush import (
-                Command as FlushCommand)
+    # NOTE: Django 1.7 does not have `management._commands` anymore, which
+    # is used by South's `patch_for_test_db_setup` and the code below.
+    if 'south' not in settings.INSTALLED_APPS or get_django_version() > (1, 7):
+        return
 
-            class SkipFlushCommand(FlushCommand):
-                def handle_noargs(self, **options):
+    from django.core import management
+
+    try:
+        # if `south` >= 0.7.1 we can use the test helper
+        from south.management.commands import patch_for_test_db_setup
+    except ImportError:
+        # if `south` < 0.7.1 make sure its migrations are disabled
+        management.get_commands()
+        management._commands['syncdb'] = 'django.core'
+    else:
+        # Monkey-patch south.hacks.django_1_0.SkipFlushCommand to load
+        # initial data.
+        # Ref: http://south.aeracode.org/ticket/1395#comment:3
+        import south.hacks.django_1_0
+        from django.core.management.commands.flush import (
+            Command as FlushCommand)
+
+        class SkipFlushCommand(FlushCommand):
+            def handle_noargs(self, **options):
+                # Reinstall the initial_data fixture.
+                from django.core.management import call_command
+                # `load_initial_data` got introduces with Django 1.5.
+                load_initial_data = options.get('load_initial_data', None)
+                if load_initial_data or load_initial_data is None:
                     # Reinstall the initial_data fixture.
-                    from django.core.management import call_command
-                    # `load_initial_data` got introduces with Django 1.5.
-                    load_initial_data = options.get('load_initial_data', None)
-                    if load_initial_data or load_initial_data is None:
-                        # Reinstall the initial_data fixture.
-                        call_command('loaddata', 'initial_data', **options)
-                    # no-op to avoid calling flush
-                    return
-            south.hacks.django_1_0.SkipFlushCommand = SkipFlushCommand
+                    call_command('loaddata', 'initial_data', **options)
+                # no-op to avoid calling flush
+                return
+        south.hacks.django_1_0.SkipFlushCommand = SkipFlushCommand
 
-            patch_for_test_db_setup()
+        patch_for_test_db_setup()
+
+
+def _disable_native_migrations():
+    from django.conf import settings
+    from .migrations import DisableMigrations
+
+    settings.MIGRATION_MODULES = DisableMigrations()
 
 
 # ############### User visible fixtures ################
@@ -135,17 +160,19 @@ def _handle_south():
 def db(request, _django_db_setup, _django_cursor_wrapper):
     """Require a django test database
 
-    This database will be setup with the default fixtures and will
-    have the transaction management disabled.  At the end of the test
-    the transaction will be rolled back to undo any changes to the
-    database.  This is more limited than the ``transactional_db``
-    resource but faster.
+    This database will be setup with the default fixtures and will have
+    the transaction management disabled. At the end of the test the outer
+    transaction that wraps the test itself will be rolled back to undo any
+    changes to the database (in case the backend supports transactions).
+    This is more limited than the ``transactional_db`` resource but
+    faster.
 
     If both this and ``transactional_db`` are requested then the
     database setup will behave as only ``transactional_db`` was
     requested.
     """
-    if 'transactional_db' in request.funcargnames:
+    if 'transactional_db' in request.funcargnames \
+            or 'live_server' in request.funcargnames:
         return request.getfuncargvalue('transactional_db')
     return _django_db_fixture_helper(False, request, _django_cursor_wrapper)
 
@@ -177,9 +204,7 @@ def client():
 
 @pytest.fixture()
 def django_user_model(db):
-    """
-    The class of Django's user model.
-    """
+    """The class of Django's user model."""
     try:
         from django.contrib.auth import get_user_model
     except ImportError:
@@ -192,9 +217,7 @@ def django_user_model(db):
 
 @pytest.fixture()
 def django_username_field(django_user_model):
-    """
-    The fieldname for the username used with Django's user model.
-    """
+    """The fieldname for the username used with Django's user model."""
     try:
         return django_user_model.USERNAME_FIELD
     except AttributeError:
@@ -204,8 +227,7 @@ def django_username_field(django_user_model):
 
 @pytest.fixture()
 def admin_user(db, django_user_model, django_username_field):
-    """
-    A Django admin user.
+    """A Django admin user.
 
     This uses an existing user with username "admin", or creates a new one with
     password "password".
@@ -226,10 +248,7 @@ def admin_user(db, django_user_model, django_username_field):
 
 @pytest.fixture()
 def admin_client(db, admin_user):
-    """
-    A Django test client logged in as an admin user (via the ``admin_user``
-    fixture).
-    """
+    """A Django test client logged in as an admin user."""
     from django.test.client import Client
 
     client = Client()
@@ -265,7 +284,7 @@ class MonkeyPatchWrapper(object):
 
 
 @pytest.fixture()
-def settings(request, monkeypatch):
+def settings(monkeypatch):
     """A Django settings object which restores changes after the testrun"""
     skip_if_no_django()
 
@@ -313,7 +332,7 @@ def live_server(request):
 
 @pytest.fixture(autouse=True, scope='function')
 def _live_server_helper(request):
-    """Helper to make live_server work, internal to pytest-django
+    """Helper to make live_server work, internal to pytest-django.
 
     This helper will dynamically request the transactional_db fixture
     for a test which uses the live_server fixture.  This allows the
