@@ -1,16 +1,8 @@
 import sys
 
-import pytest
-
 from .lazy_django import get_django_version
 
 
-def supported():
-    import django.test.testcases
-
-    return hasattr(django.test.testcases, 'LiveServerThread')
-
-
 class LiveServer(object):
     """The liveserver fixture
 
@@ -20,18 +12,15 @@ class LiveServer(object):
     """
 
     def __init__(self, addr):
-        try:
-            from django.test.testcases import LiveServerThread
-        except ImportError:
-            pytest.skip('live_server tests not supported in Django < 1.4')
         from django.db import connections
+        from django.test.testcases import LiveServerThread
 
         connections_override = {}
         for conn in connections.all():
             # If using in-memory sqlite databases, pass the connections to
             # the server thread.
-            if (conn.settings_dict['ENGINE'] == 'django.db.backends.sqlite3'
-                    and conn.settings_dict['NAME'] == ':memory:'):
+            if (conn.settings_dict['ENGINE'] == 'django.db.backends.sqlite3' and
+                    conn.settings_dict['NAME'] == ':memory:'):
                 # Explicitly enable thread-shareability for this connection
                 conn.allow_thread_sharing = True
                 connections_override[conn.alias] = conn
